//
//  IDIDevice.h
//  iDeviceInterface
//
//  Created by Chris Devor on 7/14/11.
//  Copyright 2011 Macroplant. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "MobileDevice.h"
#import "IDDeviceConnectionManager.h"

extern NSString* AFCADDRESS;
extern NSString* AFC2ADDRESS;

@interface IDDeviceAppDirectoryItem : NSObject {
   
   NSString *name;
   NSString* ID;
   NSString* iconPath;
   NSString* appFolder;
}
@property(readwrite, retain) NSString *name;
@property(readwrite, retain) NSString *ID;
@property(readwrite, retain) NSString *iconPath;
@property(readwrite, retain) NSString *appFolder;

@end


@interface IDIDevice : NSObject {
   
   NSLock* lock_connectionLock;
   
   struct am_device *myDevice;
	struct afc_connection *myConnection;
	
	afc_file_ref myLockRef;
	BOOL isJailbreaked;
   BOOL isConnected;
   
   NSString* deviceName;
   NSMutableArray* appBundles;
   
   NSString* currentService;
   
   NSObject <IDDeviceConnectionManagerDelegate> *delegate;
}
@property(readonly) struct am_device *myDevice;
//@property(readonly) struct afc_connection *myConnection;
@property(readonly) BOOL isJailbreaked;
@property(readonly) BOOL isUsingAFC2;
@property(readonly) BOOL isConnected;
@property (readonly) NSString* currentService;


@property (readonly) NSString* deviceName;
@property (readonly) NSString* activationState;
@property (readonly) NSString* activationStateAcknowledged;
@property (readonly) NSString* basebandBootloaderVersion;
@property (readonly) NSString* basebandVersion;
@property (readonly) NSString* bluetoothAddress;
@property (readonly) NSString* buildVersion;
@property (readonly) NSString* deviceCertificate;
@property (readonly) NSString* deviceClass;
@property (readonly) NSString* devicePublicKey;
@property (readonly) NSString* firmwareVersion;
@property (readonly) NSString* fostAttached;
@property (readonly) NSString* integratedCircuitCardIdentity;
@property (readonly) NSString* internationalMobileEquipmentIdentity;
@property (readonly) NSString* internationalMobileSubscriberIdentity;
@property (readonly) NSString* modelNumber;
@property (readonly) NSString* phoneNumber;
@property (readonly) NSString* productType;
@property (readonly) NSString* productVersion;
@property (readonly) NSString* protocolVersion;
@property (readonly) NSString* regionInfo;
@property (readonly) NSString* sBLockdownEverRegisteredKey;
@property (readonly) NSString* sIMStatus;
@property (readonly) NSString* serialNumber;
@property (readonly) NSString* somebodySetTimeZone;
@property (readonly) NSString* timeIntervalSince1970;
@property (readonly) NSString* timeZone;
@property (readonly) NSString* timeZoneOffsetFromUTC;
@property (readonly) NSString* trustedHostAttached;
@property (readonly) NSString* uniqueDeviceID;
@property (readonly) NSString* uses24HourClock;
@property (readonly) NSString* wiFiAddress;
@property (readonly) NSString* iTunesHasConnected;


- (id)initWithDevice:(struct am_device *)thisDevice allowAFC2:(BOOL) allowAFC2 delegate:(NSObject <IDDeviceConnectionManagerDelegate>*) del;

- (BOOL) restartSession;
- (BOOL) connectToService:(NSString*) newService;

- (BOOL) copyPathToComputerFromDevice:(NSString *)sourcePathOnDevice destinationOnComputer:(NSString *)destinationPathOnComputer serviceName:(NSString*)service;
- (BOOL) copyPathToDeviceFromComputer:(NSString *)sourcePathOnComputer targetPath:(NSString *) targetPathOnDevice serviceName:(NSString*)service;

- (NSArray*) appBundles;
- (NSDictionary *) GetFileInfo:(NSString *)path serviceName:(NSString*)service;

- (BOOL) createNewFolder:(NSString *)folderPath serviceName:(NSString*)service;
- (BOOL) renameFolder:(NSString *)folderPath newFolderName:(NSString *)newFolderName serviceName:(NSString*)service;
- (BOOL) removePath:(NSString *) folderPath serviceName:(NSString*)service;
- (BOOL) fileExistsOnDevice:(NSString *) thisPath serviceName:(NSString*)service;
- (BOOL) directoryExistsOnDevice:(NSString *)thisPath serviceName:(NSString*)service;

- (BOOL) isDirectory:(NSString *)path serviceName:(NSString*)service;
- (NSNumber *) getFileSize:(NSString *)path serviceName:(NSString*)service;

- (NSArray *) contentsInDirectory:(NSString *)directoryPath includeHiddenFiles:(BOOL)includeHidden serviceName:(NSString*)service;
- (NSArray *) sortedContentsInDirectory:(NSString *)directoryPath includeHiddenFiles:(BOOL)includeHidden serviceName:(NSString*)service;
- (NSArray *) getDirectories:(NSString *)directoryPath includeHidden:(BOOL)includeHidden serviceName:(NSString*)service;
- (NSArray *) getFiles:(NSString *)directoryPath includeHidden:(BOOL)includeHidden serviceName:(NSString*)service;

- (NSDictionary *) getDeviceInfo;
- (NSNumber *) getDeviceCapacity;
- (NSNumber *) getDeviceFreeSpace;

- (NSNumber *) getFileSize:(NSString *)path serviceName:(NSString*)service;
- (NSDate *) getDateModified:(NSString *)path serviceName:(NSString*)service;



@end
